@@ -6,6 +6,8 @@
  */
 
 #include "filteractionaddtag.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "filter/dialog/filteractionmissingtagdialog.h"
 #include "filter/filtermanager.h"
 
@@ -32,10 +34,8 @@ QWidget *FilterActionAddTag::createParamWidget(QWidget *parent) const
     mComboBox = new QComboBox(parent);
     mComboBox->setMinimumWidth(50);
     mComboBox->setEditable(false);
-    QMapIterator<QUrl, QString> i(mList);
-    while (i.hasNext()) {
-        i.next();
-        mComboBox->addItem(i.value(), i.key());
+    for (const auto &[key, value] : mList.asKeyValueRange()) {
+        mComboBox->addItem(value, key);
     }
 
     setParamWidgetValue(mComboBox);
@@ -77,10 +77,8 @@ void FilterActionAddTag::slotTagListingFinished()
 
 void FilterActionAddTag::fillComboBox()
 {
-    QMapIterator<QUrl, QString> i(mList);
-    while (i.hasNext()) {
-        i.next();
-        mComboBox->addItem(i.value(), i.key());
+    for (const auto &[key, value] : mList.asKeyValueRange()) {
+        mComboBox->addItem(value, key);
     }
 }
 
@@ -146,7 +144,7 @@ QString FilterActionAddTag::displayString() const
 
 QString FilterActionAddTag::informationAboutNotValidAction() const
 {
-    const QString info = name() + QLatin1Char('\n') + i18n("No tag selected.");
+    const QString info = name() + u'\n' + i18n("No tag selected.");
     return info;
 }
 
